Class: Google::Apis::CssV1::Certification

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/css_v1/classes.rb,
lib/google/apis/css_v1/representations.rb,
lib/google/apis/css_v1/representations.rb

Overview

The certification for the product. Use the this attribute to describe certifications, such as energy efficiency ratings, associated with a product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Certification

Returns a new instance of Certification.



533
534
535
# File 'lib/google/apis/css_v1/classes.rb', line 533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorityString

The authority or certification body responsible for issuing the certification. At this time, the most common value is "EC" or “European_Commission” for energy labels in the EU. Corresponds to the JSON property authority

Returns:

  • (String)


517
518
519
# File 'lib/google/apis/css_v1/classes.rb', line 517

def authority
  @authority
end

#codeString

The code of the certification. For example, for the EPREL certificate with the link https://eprel.ec.europa.eu/screen/product/dishwashers2019/123456 the code is 123456. The code is required for European Energy Labels. Corresponds to the JSON property code

Returns:

  • (String)


524
525
526
# File 'lib/google/apis/css_v1/classes.rb', line 524

def code
  @code
end

#nameString

The name of the certification. At this time, the most common value is "EPREL", which represents energy efficiency certifications in the EU European Registry for Energy Labeling (EPREL) database. Corresponds to the JSON property name

Returns:

  • (String)


531
532
533
# File 'lib/google/apis/css_v1/classes.rb', line 531

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



538
539
540
541
542
# File 'lib/google/apis/css_v1/classes.rb', line 538

def update!(**args)
  @authority = args[:authority] if args.key?(:authority)
  @code = args[:code] if args.key?(:code)
  @name = args[:name] if args.key?(:name)
end