Class: Google::Apis::CssV1::CssProduct

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/css_v1/classes.rb,
lib/google/apis/css_v1/representations.rb,
lib/google/apis/css_v1/representations.rb

Overview

The processed CSS Product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CssProduct

Returns a new instance of CssProduct.



591
592
593
# File 'lib/google/apis/css_v1/classes.rb', line 591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesGoogle::Apis::CssV1::Attributes

Attributes for CSS Product. Corresponds to the JSON property attributes



552
553
554
# File 'lib/google/apis/css_v1/classes.rb', line 552

def attributes
  @attributes
end

#content_languageString

Output only. The two-letter ISO 639-1 language code for the product. Corresponds to the JSON property contentLanguage

Returns:

  • (String)


558
559
560
# File 'lib/google/apis/css_v1/classes.rb', line 558

def content_language
  @content_language
end

#css_product_statusGoogle::Apis::CssV1::CssProductStatus

The status of the Css Product, data validation issues, that is, information about the Css Product computed asynchronously. Corresponds to the JSON property cssProductStatus



564
565
566
# File 'lib/google/apis/css_v1/classes.rb', line 564

def css_product_status
  @css_product_status
end

#custom_attributesArray<Google::Apis::CssV1::CustomAttribute>

Output only. A list of custom (CSS-provided) attributes. It can also be used to submit any attribute of the feed specification in its generic form (for example, "name": "size type", "value": "regular"). This is useful for submitting attributes not explicitly exposed by the API, such as additional attributes used for Buy on Google. Corresponds to the JSON property customAttributes



573
574
575
# File 'lib/google/apis/css_v1/classes.rb', line 573

def custom_attributes
  @custom_attributes
end

#feed_labelString

Output only. The feed label for the product. Corresponds to the JSON property feedLabel

Returns:

  • (String)


578
579
580
# File 'lib/google/apis/css_v1/classes.rb', line 578

def feed_label
  @feed_label
end

#nameString

The name of the CSS Product. Format: "accounts/account/cssProducts/ css_product" Corresponds to the JSON property name

Returns:

  • (String)


584
585
586
# File 'lib/google/apis/css_v1/classes.rb', line 584

def name
  @name
end

#raw_provided_idString

Output only. Your unique raw identifier for the product. Corresponds to the JSON property rawProvidedId

Returns:

  • (String)


589
590
591
# File 'lib/google/apis/css_v1/classes.rb', line 589

def raw_provided_id
  @raw_provided_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



596
597
598
599
600
601
602
603
604
# File 'lib/google/apis/css_v1/classes.rb', line 596

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @content_language = args[:content_language] if args.key?(:content_language)
  @css_product_status = args[:css_product_status] if args.key?(:css_product_status)
  @custom_attributes = args[:custom_attributes] if args.key?(:custom_attributes)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @name = args[:name] if args.key?(:name)
  @raw_provided_id = args[:raw_provided_id] if args.key?(:raw_provided_id)
end