Class: Google::Apis::CssV1::CssProductStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/css_v1/classes.rb,
lib/google/apis/css_v1/representations.rb,
lib/google/apis/css_v1/representations.rb

Overview

The status of the Css Product, data validation issues, that is, information about the Css Product computed asynchronously.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CssProductStatus

Returns a new instance of CssProductStatus.



727
728
729
# File 'lib/google/apis/css_v1/classes.rb', line 727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_dateString

Date on which the item has been created, in ISO 8601 format. Corresponds to the JSON property creationDate

Returns:

  • (String)


703
704
705
# File 'lib/google/apis/css_v1/classes.rb', line 703

def creation_date
  @creation_date
end

#destination_statusesArray<Google::Apis::CssV1::DestinationStatus>

The intended destinations for the product. Corresponds to the JSON property destinationStatuses



708
709
710
# File 'lib/google/apis/css_v1/classes.rb', line 708

def destination_statuses
  @destination_statuses
end

#google_expiration_dateString

Date on which the item expires, in ISO 8601 format. Corresponds to the JSON property googleExpirationDate

Returns:

  • (String)


714
715
716
# File 'lib/google/apis/css_v1/classes.rb', line 714

def google_expiration_date
  @google_expiration_date
end

#item_level_issuesArray<Google::Apis::CssV1::ItemLevelIssue>

A list of all issues associated with the product. Corresponds to the JSON property itemLevelIssues



719
720
721
# File 'lib/google/apis/css_v1/classes.rb', line 719

def item_level_issues
  @item_level_issues
end

#last_update_dateString

Date on which the item has been last updated, in ISO 8601 format. Corresponds to the JSON property lastUpdateDate

Returns:

  • (String)


725
726
727
# File 'lib/google/apis/css_v1/classes.rb', line 725

def last_update_date
  @last_update_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



732
733
734
735
736
737
738
# File 'lib/google/apis/css_v1/classes.rb', line 732

def update!(**args)
  @creation_date = args[:creation_date] if args.key?(:creation_date)
  @destination_statuses = args[:destination_statuses] if args.key?(:destination_statuses)
  @google_expiration_date = args[:google_expiration_date] if args.key?(:google_expiration_date)
  @item_level_issues = args[:item_level_issues] if args.key?(:item_level_issues)
  @last_update_date = args[:last_update_date] if args.key?(:last_update_date)
end