Class: Google::Apis::CssV1::CssService

Inherits:
Google::Apis::Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/css_v1/service.rb

Overview

CSS API

Programmatically manage your Comparison Shopping Service (CSS) account data at scale.

Examples:

require 'google/apis/css_v1'

Css = Google::Apis::CssV1 # Alias the module
service = Css::CssService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://css.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeCssService

Returns a new instance of CssService.



48
49
50
51
52
53
# File 'lib/google/apis/css_v1/service.rb', line 48

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-css_v1',
        client_version: Google::Apis::CssV1::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



41
42
43
# File 'lib/google/apis/css_v1/service.rb', line 41

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



46
47
48
# File 'lib/google/apis/css_v1/service.rb', line 46

def quota_user
  @quota_user
end

Instance Method Details

#create_account_label(parent, account_label_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::AccountLabel

Creates a new label, not assigned to any account.

Parameters:

  • parent (String)

    Required. The parent account. Format: accounts/account

  • account_label_object (Google::Apis::CssV1::AccountLabel) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



403
404
405
406
407
408
409
410
411
412
413
# File 'lib/google/apis/css_v1/service.rb', line 403

def (parent,  = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/labels', options)
  command.request_representation = Google::Apis::CssV1::AccountLabel::Representation
  command.request_object = 
  command.response_representation = Google::Apis::CssV1::AccountLabel::Representation
  command.response_class = Google::Apis::CssV1::AccountLabel
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_account_css_product_input(name, supplemental_feed_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::Empty

Deletes a CSS Product input from your CSS Center account. After a delete it may take several minutes until the input is no longer available.

Parameters:

  • name (String)

    Required. The name of the CSS product input resource to delete. Format: accounts/account/cssProductInputs/css_product_input, where the last section css_product_input consists of 3 parts: contentLanguage~feedLabel~ offerId. Example: accounts/123/cssProductInputs/de~DE~rawProvidedId123

  • supplemental_feed_id (Fixnum) (defaults to: nil)

    The Content API Supplemental Feed ID. The field must not be set if the action applies to a primary feed. If the field is set, then product action applies to a supplemental feed instead of primary Content API feed.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



200
201
202
203
204
205
206
207
208
209
# File 'lib/google/apis/css_v1/service.rb', line 200

def (name, supplemental_feed_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CssV1::Empty::Representation
  command.response_class = Google::Apis::CssV1::Empty
  command.params['name'] = name unless name.nil?
  command.query['supplementalFeedId'] = supplemental_feed_id unless supplemental_feed_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_account_label(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::Empty

Deletes a label and removes it from all accounts to which it was assigned.

Parameters:

  • name (String)

    Required. The name of the label to delete. Format: accounts/account/labels/ label

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



436
437
438
439
440
441
442
443
444
# File 'lib/google/apis/css_v1/service.rb', line 436

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CssV1::Empty::Representation
  command.response_class = Google::Apis::CssV1::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_account(name, parent: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::Account

Retrieves a single CSS/MC account by ID.

Parameters:

  • name (String)

    Required. The name of the managed CSS/MC account. Format: accounts/account

  • parent (String) (defaults to: nil)

    Optional. Only required when retrieving MC account information. The CSS domain that is the parent resource of the MC account. Format: accounts/account

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



78
79
80
81
82
83
84
85
86
87
# File 'lib/google/apis/css_v1/service.rb', line 78

def (name, parent: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CssV1::Account::Representation
  command.response_class = Google::Apis::CssV1::Account
  command.params['name'] = name unless name.nil?
  command.query['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_account_css_product(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::CssProduct

Retrieves the processed CSS Product from your CSS Center account. After inserting, updating, or deleting a product input, it may take several minutes before the updated final product can be retrieved.

Parameters:

  • name (String)

    Required. The name of the CSS product to retrieve. Format: accounts/account/ cssProducts/css_product``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



327
328
329
330
331
332
333
334
335
# File 'lib/google/apis/css_v1/service.rb', line 327

def (name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::CssV1::CssProduct::Representation
  command.response_class = Google::Apis::CssV1::CssProduct
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#insert_account_css_product_input(parent, css_product_input_object = nil, feed_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::CssProductInput

Uploads a CssProductInput to your CSS Center account. If an input with the same contentLanguage, identity, feedLabel and feedId already exists, this method replaces that entry. After inserting, updating, or deleting a CSS Product input, it may take several minutes before the processed CSS Product can be retrieved.

Parameters:

  • parent (String)

    Required. The account where this CSS Product will be inserted. Format: accounts/account

  • css_product_input_object (Google::Apis::CssV1::CssProductInput) (defaults to: nil)
  • feed_id (Fixnum) (defaults to: nil)

    Optional. DEPRECATED. Feed id is not required for CSS Products. The primary or supplemental feed id. If CSS Product already exists and feed id provided is different, then the CSS Product will be moved to a new feed. Note: For now, CSSs do not need to provide feed ids as we create feeds on the fly. We do not have supplemental feed support for CSS Products yet.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/google/apis/css_v1/service.rb', line 243

def (parent, css_product_input_object = nil, feed_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+parent}/cssProductInputs:insert', options)
  command.request_representation = Google::Apis::CssV1::CssProductInput::Representation
  command.request_object = css_product_input_object
  command.response_representation = Google::Apis::CssV1::CssProductInput::Representation
  command.response_class = Google::Apis::CssV1::CssProductInput
  command.params['parent'] = parent unless parent.nil?
  command.query['feedId'] = feed_id unless feed_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_child_accounts(parent, full_name: nil, label_id: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::ListChildAccountsResponse

Lists all the accounts under the specified CSS account ID, and optionally filters by label ID and account name.

Parameters:

  • parent (String)

    Required. The parent account. Must be a CSS group or domain. Format: accounts/ account

  • full_name (String) (defaults to: nil)

    If set, only the MC accounts with the given name (case sensitive) will be returned.

  • label_id (Fixnum) (defaults to: nil)

    If set, only the MC accounts with the given label ID will be returned.

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of accounts to return. The service may return fewer than this value. If unspecified, at most 50 accounts will be returned. The maximum value is 100; values above 100 will be coerced to 100.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListChildAccounts call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListChildAccounts must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/google/apis/css_v1/service.rb', line 125

def (parent, full_name: nil, label_id: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}:listChildAccounts', options)
  command.response_representation = Google::Apis::CssV1::ListChildAccountsResponse::Representation
  command.response_class = Google::Apis::CssV1::ListChildAccountsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fullName'] = full_name unless full_name.nil?
  command.query['labelId'] = label_id unless label_id.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_css_products(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::ListCssProductsResponse

Lists the processed CSS Products in your CSS Center account. The response might contain fewer items than specified by pageSize. Rely on pageToken to determine if there are more items to be requested. After inserting, updating, or deleting a CSS product input, it may take several minutes before the updated processed CSS product can be retrieved.

Parameters:

  • parent (String)

    Required. The account/domain to list processed CSS Products for. Format: accounts/account

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of CSS Products to return. The service may return fewer than this value. The maximum value is 1000; values above 1000 will be coerced to 1000. If unspecified, the maximum number of CSS products will be returned.

  • page_token (String) (defaults to: nil)

    A page token, received from a previous ListCssProducts call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListCssProducts must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



370
371
372
373
374
375
376
377
378
379
380
# File 'lib/google/apis/css_v1/service.rb', line 370

def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/cssProducts', options)
  command.response_representation = Google::Apis::CssV1::ListCssProductsResponse::Representation
  command.response_class = Google::Apis::CssV1::ListCssProductsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_labels(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::ListAccountLabelsResponse

Lists the labels owned by an account.

Parameters:

  • parent (String)

    Required. The parent account. Format: accounts/account

  • page_size (Fixnum) (defaults to: nil)

    The maximum number of labels to return. The service may return fewer than this value. If unspecified, at most 50 labels will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

  • page_token (String) (defaults to: nil)

    A page token, received from a previous ListAccountLabels call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListAccountLabels must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



475
476
477
478
479
480
481
482
483
484
485
# File 'lib/google/apis/css_v1/service.rb', line 475

def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/labels', options)
  command.response_representation = Google::Apis::CssV1::ListAccountLabelsResponse::Representation
  command.response_class = Google::Apis::CssV1::ListAccountLabelsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_account_quotas(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::ListQuotaGroupsResponse

Lists the daily call quota and usage per group for your CSS Center account.

Parameters:

  • parent (String)

    Required. The CSS account that owns the collection of method quotas and resources. In most cases, this is the CSS domain. Format: accounts/account

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of quotas to return in the response, used for paging. Defaults to 500; values above 1000 will be coerced to 1000.

  • page_token (String) (defaults to: nil)

    Optional. Token (if provided) to retrieve the subsequent page. All other parameters must match the original call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



548
549
550
551
552
553
554
555
556
557
558
# File 'lib/google/apis/css_v1/service.rb', line 548

def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1/{+parent}/quotas', options)
  command.response_representation = Google::Apis::CssV1::ListQuotaGroupsResponse::Representation
  command.response_class = Google::Apis::CssV1::ListQuotaGroupsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_account_css_product_input(name, css_product_input_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::CssProductInput

Updates the existing Css Product input in your CSS Center account. After inserting, updating, or deleting a CSS Product input, it may take several minutes before the processed Css Product can be retrieved.

Parameters:

  • name (String)

    Identifier. The name of the CSS Product input. Format: accounts/account/ cssProductInputs/css_product_input`, where the last section css_product_input` consists of 3 parts: contentLanguage~feedLabel~offerId. Example: accounts/123/cssProductInputs/de~DE~rawProvidedId123

  • css_product_input_object (Google::Apis::CssV1::CssProductInput) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    The list of CSS product attributes to be updated. If the update mask is omitted, then it is treated as implied field mask equivalent to all fields that are populated (have a non-empty value). Attributes specified in the update mask without a value specified in the body will be deleted from the CSS product. Update mask can only be specified for top level fields in attributes and custom attributes. To specify the update mask for custom attributes you need to add the custom_attribute. prefix. Providing special "*" value for full CSS product replacement is not supported.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/google/apis/css_v1/service.rb', line 291

def (name, css_product_input_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::CssV1::CssProductInput::Representation
  command.request_object = css_product_input_object
  command.response_representation = Google::Apis::CssV1::CssProductInput::Representation
  command.response_class = Google::Apis::CssV1::CssProductInput
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_account_label(name, account_label_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::AccountLabel

Updates a label.

Parameters:

  • name (String)

    Identifier. The resource name of the label. Format: accounts/account/labels/ label

  • account_label_object (Google::Apis::CssV1::AccountLabel) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



509
510
511
512
513
514
515
516
517
518
519
# File 'lib/google/apis/css_v1/service.rb', line 509

def (name,  = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1/{+name}', options)
  command.request_representation = Google::Apis::CssV1::AccountLabel::Representation
  command.request_object = 
  command.response_representation = Google::Apis::CssV1::AccountLabel::Representation
  command.response_class = Google::Apis::CssV1::AccountLabel
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#update_account_labels(name, update_account_labels_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CssV1::Account

Updates labels assigned to CSS/MC accounts by a CSS domain.

Parameters:

  • name (String)

    Required. The label resource name. Format: accounts/account

  • update_account_labels_request_object (Google::Apis::CssV1::UpdateAccountLabelsRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



160
161
162
163
164
165
166
167
168
169
170
# File 'lib/google/apis/css_v1/service.rb', line 160

def (name,  = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1/{+name}:updateLabels', options)
  command.request_representation = Google::Apis::CssV1::UpdateAccountLabelsRequest::Representation
  command.request_object = 
  command.response_representation = Google::Apis::CssV1::Account::Representation
  command.response_class = Google::Apis::CssV1::Account
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end