Class: Google::Apis::CssV1::HeadlineOfferInstallment
- Inherits:
-
Object
- Object
- Google::Apis::CssV1::HeadlineOfferInstallment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/css_v1/classes.rb,
lib/google/apis/css_v1/representations.rb,
lib/google/apis/css_v1/representations.rb
Overview
A message that represents installment.
Instance Attribute Summary collapse
-
#amount ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
-
#downpayment ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
-
#months ⇒ Fixnum
The number of installments the buyer has to pay.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HeadlineOfferInstallment
constructor
A new instance of HeadlineOfferInstallment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HeadlineOfferInstallment
Returns a new instance of HeadlineOfferInstallment.
849 850 851 |
# File 'lib/google/apis/css_v1/classes.rb', line 849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
Corresponds to the JSON property amount
837 838 839 |
# File 'lib/google/apis/css_v1/classes.rb', line 837 def amount @amount end |
#downpayment ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
Corresponds to the JSON property downpayment
842 843 844 |
# File 'lib/google/apis/css_v1/classes.rb', line 842 def downpayment @downpayment end |
#months ⇒ Fixnum
The number of installments the buyer has to pay.
Corresponds to the JSON property months
847 848 849 |
# File 'lib/google/apis/css_v1/classes.rb', line 847 def months @months end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
854 855 856 857 858 |
# File 'lib/google/apis/css_v1/classes.rb', line 854 def update!(**args) @amount = args[:amount] if args.key?(:amount) @downpayment = args[:downpayment] if args.key?(:downpayment) @months = args[:months] if args.key?(:months) end |