Class: Google::Apis::CssV1::ItemLevelIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/css_v1/classes.rb,
lib/google/apis/css_v1/representations.rb,
lib/google/apis/css_v1/representations.rb

Overview

The ItemLevelIssue of the product status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ItemLevelIssue

Returns a new instance of ItemLevelIssue.



942
943
944
# File 'lib/google/apis/css_v1/classes.rb', line 942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicable_countriesArray<String>

List of country codes (ISO 3166-1 alpha-2) where issue applies to the CSS Product. Corresponds to the JSON property applicableCountries

Returns:

  • (Array<String>)


900
901
902
# File 'lib/google/apis/css_v1/classes.rb', line 900

def applicable_countries
  @applicable_countries
end

#attributeString

The attribute's name, if the issue is caused by a single attribute. Corresponds to the JSON property attribute

Returns:

  • (String)


905
906
907
# File 'lib/google/apis/css_v1/classes.rb', line 905

def attribute
  @attribute
end

#codeString

The error code of the issue. Corresponds to the JSON property code

Returns:

  • (String)


910
911
912
# File 'lib/google/apis/css_v1/classes.rb', line 910

def code
  @code
end

#descriptionString

A short issue description in English. Corresponds to the JSON property description

Returns:

  • (String)


915
916
917
# File 'lib/google/apis/css_v1/classes.rb', line 915

def description
  @description
end

#destinationString

The destination the issue applies to. Corresponds to the JSON property destination

Returns:

  • (String)


920
921
922
# File 'lib/google/apis/css_v1/classes.rb', line 920

def destination
  @destination
end

#detailString

A detailed issue description in English. Corresponds to the JSON property detail

Returns:

  • (String)


925
926
927
# File 'lib/google/apis/css_v1/classes.rb', line 925

def detail
  @detail
end

#documentationString

The URL of a web page to help with resolving this issue. Corresponds to the JSON property documentation

Returns:

  • (String)


930
931
932
# File 'lib/google/apis/css_v1/classes.rb', line 930

def documentation
  @documentation
end

#resolutionString

Whether the issue can be resolved by the merchant. Corresponds to the JSON property resolution

Returns:

  • (String)


935
936
937
# File 'lib/google/apis/css_v1/classes.rb', line 935

def resolution
  @resolution
end

#servabilityString

How this issue affects serving of the CSS Product. Corresponds to the JSON property servability

Returns:

  • (String)


940
941
942
# File 'lib/google/apis/css_v1/classes.rb', line 940

def servability
  @servability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



947
948
949
950
951
952
953
954
955
956
957
# File 'lib/google/apis/css_v1/classes.rb', line 947

def update!(**args)
  @applicable_countries = args[:applicable_countries] if args.key?(:applicable_countries)
  @attribute = args[:attribute] if args.key?(:attribute)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
  @destination = args[:destination] if args.key?(:destination)
  @detail = args[:detail] if args.key?(:detail)
  @documentation = args[:documentation] if args.key?(:documentation)
  @resolution = args[:resolution] if args.key?(:resolution)
  @servability = args[:servability] if args.key?(:servability)
end