Class: Google::Apis::CssV1::UpdateAccountLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/css_v1/classes.rb,
lib/google/apis/css_v1/representations.rb,
lib/google/apis/css_v1/representations.rb

Overview

The request message for the UpdateLabels method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateAccountLabelsRequest

Returns a new instance of UpdateAccountLabelsRequest.



1283
1284
1285
# File 'lib/google/apis/css_v1/classes.rb', line 1283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_idsArray<Fixnum>

The list of label IDs to overwrite the existing account label IDs. If the list is empty, all currently assigned label IDs will be deleted. Corresponds to the JSON property labelIds

Returns:

  • (Array<Fixnum>)


1275
1276
1277
# File 'lib/google/apis/css_v1/classes.rb', line 1275

def label_ids
  @label_ids
end

#parentString

Optional. Only required when updating MC account labels. The CSS domain that is the parent resource of the MC account. Format: accounts/account Corresponds to the JSON property parent

Returns:

  • (String)


1281
1282
1283
# File 'lib/google/apis/css_v1/classes.rb', line 1281

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1288
1289
1290
1291
# File 'lib/google/apis/css_v1/classes.rb', line 1288

def update!(**args)
  @label_ids = args[:label_ids] if args.key?(:label_ids)
  @parent = args[:parent] if args.key?(:parent)
end