Class: Google::Apis::CssV1::Attributes
- Inherits:
-
Object
- Object
- Google::Apis::CssV1::Attributes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/css_v1/classes.rb,
lib/google/apis/css_v1/representations.rb,
lib/google/apis/css_v1/representations.rb
Overview
Attributes for CSS Product.
Instance Attribute Summary collapse
-
#additional_image_links ⇒ Array<String>
Additional URL of images of the item.
-
#adult ⇒ Boolean
(also: #adult?)
Set to true if the item is targeted towards adults.
-
#age_group ⇒ String
Target age group of the item.
-
#brand ⇒ String
Product Related Attributes.[14-36] Brand of the item.
-
#certifications ⇒ Array<Google::Apis::CssV1::Certification>
A list of certificates claimed by the CSS for the given product.
-
#color ⇒ String
Color of the item.
-
#cpp_ads_redirect ⇒ String
Allows advertisers to override the item URL when the product is shown within the context of Product Ads.
-
#cpp_link ⇒ String
URL directly linking to your the Product Detail Page of the CSS.
-
#cpp_mobile_link ⇒ String
URL for the mobile-optimized version of the Product Detail Page of the CSS.
-
#custom_label0 ⇒ String
Custom label 0 for custom grouping of items in a Shopping campaign.
-
#custom_label1 ⇒ String
Custom label 1 for custom grouping of items in a Shopping campaign.
-
#custom_label2 ⇒ String
Custom label 2 for custom grouping of items in a Shopping campaign.
-
#custom_label3 ⇒ String
Custom label 3 for custom grouping of items in a Shopping campaign.
-
#custom_label4 ⇒ String
Custom label 4 for custom grouping of items in a Shopping campaign.
-
#description ⇒ String
Description of the item.
-
#excluded_destinations ⇒ Array<String>
The list of destinations to exclude for this target (corresponds to unchecked check boxes in Merchant Center).
-
#expiration_date ⇒ String
Date on which the item should expire, as specified upon insertion, in ISO 8601 format.
-
#gender ⇒ String
Target gender of the item.
-
#google_product_category ⇒ String
Google's category of the item (see Google product taxonomy).
-
#gtin ⇒ String
Global Trade Item Number (GTIN) of the item.
-
#headline_offer_condition ⇒ String
Condition of the headline offer.
-
#headline_offer_installment ⇒ Google::Apis::CssV1::HeadlineOfferInstallment
A message that represents installment.
-
#headline_offer_link ⇒ String
Link to the headline offer.
-
#headline_offer_mobile_link ⇒ String
Mobile Link to the headline offer.
-
#headline_offer_price ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
-
#headline_offer_shipping_price ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
-
#headline_offer_subscription_cost ⇒ Google::Apis::CssV1::HeadlineOfferSubscriptionCost
The SubscriptionCost of the product.
-
#high_price ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
-
#image_link ⇒ String
URL of an image of the item.
-
#included_destinations ⇒ Array<String>
The list of destinations to include for this target (corresponds to checked check boxes in Merchant Center).
-
#is_bundle ⇒ Boolean
(also: #is_bundle?)
Whether the item is a merchant-defined bundle.
-
#item_group_id ⇒ String
Shared identifier for all variants of the same product.
-
#low_price ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
-
#material ⇒ String
The material of which the item is made.
-
#max_rating ⇒ Fixnum
Maximum rating score of the product.
-
#min_rating ⇒ Fixnum
Minimum rating score of the product.
-
#mpn ⇒ String
Manufacturer Part Number (MPN) of the item.
-
#multipack ⇒ Fixnum
The number of identical products in a merchant-defined multipack.
-
#number_of_offers ⇒ Fixnum
The number of CSS Products.
-
#pattern ⇒ String
The item's pattern (e.g. polka dots).
-
#pause ⇒ String
Publication of this item will be temporarily paused.
-
#product_details ⇒ Array<Google::Apis::CssV1::ProductDetail>
Technical specification or additional product details.
-
#product_height ⇒ Google::Apis::CssV1::ProductDimension
The dimension of the product.
-
#product_highlights ⇒ Array<String>
Bullet points describing the most relevant highlights of a product.
-
#product_length ⇒ Google::Apis::CssV1::ProductDimension
The dimension of the product.
-
#product_types ⇒ Array<String>
Categories of the item (formatted as in products data specification).
-
#product_weight ⇒ Google::Apis::CssV1::ProductWeight
The weight of the product.
-
#product_width ⇒ Google::Apis::CssV1::ProductDimension
The dimension of the product.
-
#rating ⇒ Float
Average rating score of the product.
-
#review_count ⇒ Fixnum
Number of reviews of the product.
-
#size ⇒ String
Size of the item.
-
#size_system ⇒ String
System in which the size is specified.
-
#size_types ⇒ Array<String>
The cut of the item.
-
#title ⇒ String
Title of the item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Attributes
constructor
A new instance of Attributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Attributes
Returns a new instance of Attributes.
444 445 446 |
# File 'lib/google/apis/css_v1/classes.rb', line 444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_image_links ⇒ Array<String>
Additional URL of images of the item.
Corresponds to the JSON property additionalImageLinks
148 149 150 |
# File 'lib/google/apis/css_v1/classes.rb', line 148 def additional_image_links @additional_image_links end |
#adult ⇒ Boolean Also known as: adult?
Set to true if the item is targeted towards adults.
Corresponds to the JSON property adult
153 154 155 |
# File 'lib/google/apis/css_v1/classes.rb', line 153 def adult @adult end |
#age_group ⇒ String
Target age group of the item.
Corresponds to the JSON property ageGroup
159 160 161 |
# File 'lib/google/apis/css_v1/classes.rb', line 159 def age_group @age_group end |
#brand ⇒ String
Product Related Attributes.[14-36] Brand of the item.
Corresponds to the JSON property brand
164 165 166 |
# File 'lib/google/apis/css_v1/classes.rb', line 164 def brand @brand end |
#certifications ⇒ Array<Google::Apis::CssV1::Certification>
A list of certificates claimed by the CSS for the given product.
Corresponds to the JSON property certifications
169 170 171 |
# File 'lib/google/apis/css_v1/classes.rb', line 169 def certifications @certifications end |
#color ⇒ String
Color of the item.
Corresponds to the JSON property color
174 175 176 |
# File 'lib/google/apis/css_v1/classes.rb', line 174 def color @color end |
#cpp_ads_redirect ⇒ String
Allows advertisers to override the item URL when the product is shown within
the context of Product Ads.
Corresponds to the JSON property cppAdsRedirect
180 181 182 |
# File 'lib/google/apis/css_v1/classes.rb', line 180 def cpp_ads_redirect @cpp_ads_redirect end |
#cpp_link ⇒ String
URL directly linking to your the Product Detail Page of the CSS.
Corresponds to the JSON property cppLink
185 186 187 |
# File 'lib/google/apis/css_v1/classes.rb', line 185 def cpp_link @cpp_link end |
#cpp_mobile_link ⇒ String
URL for the mobile-optimized version of the Product Detail Page of the CSS.
Corresponds to the JSON property cppMobileLink
190 191 192 |
# File 'lib/google/apis/css_v1/classes.rb', line 190 def cpp_mobile_link @cpp_mobile_link end |
#custom_label0 ⇒ String
Custom label 0 for custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel0
195 196 197 |
# File 'lib/google/apis/css_v1/classes.rb', line 195 def custom_label0 @custom_label0 end |
#custom_label1 ⇒ String
Custom label 1 for custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel1
200 201 202 |
# File 'lib/google/apis/css_v1/classes.rb', line 200 def custom_label1 @custom_label1 end |
#custom_label2 ⇒ String
Custom label 2 for custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel2
205 206 207 |
# File 'lib/google/apis/css_v1/classes.rb', line 205 def custom_label2 @custom_label2 end |
#custom_label3 ⇒ String
Custom label 3 for custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel3
210 211 212 |
# File 'lib/google/apis/css_v1/classes.rb', line 210 def custom_label3 @custom_label3 end |
#custom_label4 ⇒ String
Custom label 4 for custom grouping of items in a Shopping campaign.
Corresponds to the JSON property customLabel4
215 216 217 |
# File 'lib/google/apis/css_v1/classes.rb', line 215 def custom_label4 @custom_label4 end |
#description ⇒ String
Description of the item.
Corresponds to the JSON property description
220 221 222 |
# File 'lib/google/apis/css_v1/classes.rb', line 220 def description @description end |
#excluded_destinations ⇒ Array<String>
The list of destinations to exclude for this target (corresponds to unchecked
check boxes in Merchant Center).
Corresponds to the JSON property excludedDestinations
226 227 228 |
# File 'lib/google/apis/css_v1/classes.rb', line 226 def excluded_destinations @excluded_destinations end |
#expiration_date ⇒ String
Date on which the item should expire, as specified upon insertion, in ISO
8601 format. The actual expiration
date is exposed in productstatuses as googleExpirationDate and might be earlier if expirationDate
is too far in the future. Note: It may take 2+ days from the expiration date
for the item to actually get deleted.
Corresponds to the JSON property expirationDate
236 237 238 |
# File 'lib/google/apis/css_v1/classes.rb', line 236 def expiration_date @expiration_date end |
#gender ⇒ String
Target gender of the item.
Corresponds to the JSON property gender
241 242 243 |
# File 'lib/google/apis/css_v1/classes.rb', line 241 def gender @gender end |
#google_product_category ⇒ String
Google's category of the item (see Google product taxonomy). When querying products, this field will
contain the user provided value. There is currently no way to get back the
auto assigned google product categories through the API.
Corresponds to the JSON property googleProductCategory
249 250 251 |
# File 'lib/google/apis/css_v1/classes.rb', line 249 def google_product_category @google_product_category end |
#gtin ⇒ String
Global Trade Item Number (GTIN) of the item.
Corresponds to the JSON property gtin
255 256 257 |
# File 'lib/google/apis/css_v1/classes.rb', line 255 def gtin @gtin end |
#headline_offer_condition ⇒ String
Condition of the headline offer.
Corresponds to the JSON property headlineOfferCondition
260 261 262 |
# File 'lib/google/apis/css_v1/classes.rb', line 260 def headline_offer_condition @headline_offer_condition end |
#headline_offer_installment ⇒ Google::Apis::CssV1::HeadlineOfferInstallment
A message that represents installment.
Corresponds to the JSON property headlineOfferInstallment
265 266 267 |
# File 'lib/google/apis/css_v1/classes.rb', line 265 def headline_offer_installment @headline_offer_installment end |
#headline_offer_link ⇒ String
Link to the headline offer.
Corresponds to the JSON property headlineOfferLink
270 271 272 |
# File 'lib/google/apis/css_v1/classes.rb', line 270 def headline_offer_link @headline_offer_link end |
#headline_offer_mobile_link ⇒ String
Mobile Link to the headline offer.
Corresponds to the JSON property headlineOfferMobileLink
275 276 277 |
# File 'lib/google/apis/css_v1/classes.rb', line 275 def headline_offer_mobile_link @headline_offer_mobile_link end |
#headline_offer_price ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
Corresponds to the JSON property headlineOfferPrice
280 281 282 |
# File 'lib/google/apis/css_v1/classes.rb', line 280 def headline_offer_price @headline_offer_price end |
#headline_offer_shipping_price ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
Corresponds to the JSON property headlineOfferShippingPrice
285 286 287 |
# File 'lib/google/apis/css_v1/classes.rb', line 285 def headline_offer_shipping_price @headline_offer_shipping_price end |
#headline_offer_subscription_cost ⇒ Google::Apis::CssV1::HeadlineOfferSubscriptionCost
The SubscriptionCost of the product.
Corresponds to the JSON property headlineOfferSubscriptionCost
290 291 292 |
# File 'lib/google/apis/css_v1/classes.rb', line 290 def headline_offer_subscription_cost @headline_offer_subscription_cost end |
#high_price ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
Corresponds to the JSON property highPrice
295 296 297 |
# File 'lib/google/apis/css_v1/classes.rb', line 295 def high_price @high_price end |
#image_link ⇒ String
URL of an image of the item.
Corresponds to the JSON property imageLink
300 301 302 |
# File 'lib/google/apis/css_v1/classes.rb', line 300 def image_link @image_link end |
#included_destinations ⇒ Array<String>
The list of destinations to include for this target (corresponds to checked
check boxes in Merchant Center). Default destinations are always included
unless provided in excludedDestinations.
Corresponds to the JSON property includedDestinations
307 308 309 |
# File 'lib/google/apis/css_v1/classes.rb', line 307 def included_destinations @included_destinations end |
#is_bundle ⇒ Boolean Also known as: is_bundle?
Whether the item is a merchant-defined bundle. A bundle is a custom grouping
of different products sold by a merchant for a single price.
Corresponds to the JSON property isBundle
313 314 315 |
# File 'lib/google/apis/css_v1/classes.rb', line 313 def is_bundle @is_bundle end |
#item_group_id ⇒ String
Shared identifier for all variants of the same product.
Corresponds to the JSON property itemGroupId
319 320 321 |
# File 'lib/google/apis/css_v1/classes.rb', line 319 def item_group_id @item_group_id end |
#low_price ⇒ Google::Apis::CssV1::Price
The price represented as a number and currency.
Corresponds to the JSON property lowPrice
324 325 326 |
# File 'lib/google/apis/css_v1/classes.rb', line 324 def low_price @low_price end |
#material ⇒ String
The material of which the item is made.
Corresponds to the JSON property material
329 330 331 |
# File 'lib/google/apis/css_v1/classes.rb', line 329 def material @material end |
#max_rating ⇒ Fixnum
Maximum rating score of the product. Required if rating is provided. This
field is for an upcoming feature and is not yet used.
Corresponds to the JSON property maxRating
335 336 337 |
# File 'lib/google/apis/css_v1/classes.rb', line 335 def @max_rating end |
#min_rating ⇒ Fixnum
Minimum rating score of the product. Required if rating is provided. This
field is for an upcoming feature and is not yet used.
Corresponds to the JSON property minRating
341 342 343 |
# File 'lib/google/apis/css_v1/classes.rb', line 341 def @min_rating end |
#mpn ⇒ String
Manufacturer Part Number (MPN) of the item.
Corresponds to the JSON property mpn
347 348 349 |
# File 'lib/google/apis/css_v1/classes.rb', line 347 def mpn @mpn end |
#multipack ⇒ Fixnum
The number of identical products in a merchant-defined multipack.
Corresponds to the JSON property multipack
352 353 354 |
# File 'lib/google/apis/css_v1/classes.rb', line 352 def multipack @multipack end |
#number_of_offers ⇒ Fixnum
The number of CSS Products.
Corresponds to the JSON property numberOfOffers
357 358 359 |
# File 'lib/google/apis/css_v1/classes.rb', line 357 def number_of_offers @number_of_offers end |
#pattern ⇒ String
The item's pattern (e.g. polka dots).
Corresponds to the JSON property pattern
362 363 364 |
# File 'lib/google/apis/css_v1/classes.rb', line 362 def pattern @pattern end |
#pause ⇒ String
Publication of this item will be temporarily paused.
Corresponds to the JSON property pause
367 368 369 |
# File 'lib/google/apis/css_v1/classes.rb', line 367 def pause @pause end |
#product_details ⇒ Array<Google::Apis::CssV1::ProductDetail>
Technical specification or additional product details.
Corresponds to the JSON property productDetails
372 373 374 |
# File 'lib/google/apis/css_v1/classes.rb', line 372 def product_details @product_details end |
#product_height ⇒ Google::Apis::CssV1::ProductDimension
The dimension of the product.
Corresponds to the JSON property productHeight
377 378 379 |
# File 'lib/google/apis/css_v1/classes.rb', line 377 def product_height @product_height end |
#product_highlights ⇒ Array<String>
Bullet points describing the most relevant highlights of a product.
Corresponds to the JSON property productHighlights
382 383 384 |
# File 'lib/google/apis/css_v1/classes.rb', line 382 def product_highlights @product_highlights end |
#product_length ⇒ Google::Apis::CssV1::ProductDimension
The dimension of the product.
Corresponds to the JSON property productLength
387 388 389 |
# File 'lib/google/apis/css_v1/classes.rb', line 387 def product_length @product_length end |
#product_types ⇒ Array<String>
Categories of the item (formatted as in products data specification).
Corresponds to the JSON property productTypes
393 394 395 |
# File 'lib/google/apis/css_v1/classes.rb', line 393 def product_types @product_types end |
#product_weight ⇒ Google::Apis::CssV1::ProductWeight
The weight of the product.
Corresponds to the JSON property productWeight
398 399 400 |
# File 'lib/google/apis/css_v1/classes.rb', line 398 def product_weight @product_weight end |
#product_width ⇒ Google::Apis::CssV1::ProductDimension
The dimension of the product.
Corresponds to the JSON property productWidth
403 404 405 |
# File 'lib/google/apis/css_v1/classes.rb', line 403 def product_width @product_width end |
#rating ⇒ Float
Average rating score of the product. The value must be within the range of [
min_rating, max_rating], inclusive. When displayed on the product page,
this rating is normalized to a scale of [1, 5] with one decimal place. If
provided, review_count, min_rating, and max_rating are also required.
This field is for an upcoming feature and is not yet used.
Corresponds to the JSON property rating
412 413 414 |
# File 'lib/google/apis/css_v1/classes.rb', line 412 def @rating end |
#review_count ⇒ Fixnum
Number of reviews of the product. Required if rating is provided. This field
is for an upcoming feature and is not yet used.
Corresponds to the JSON property reviewCount
418 419 420 |
# File 'lib/google/apis/css_v1/classes.rb', line 418 def review_count @review_count end |
#size ⇒ String
Size of the item. Only one value is allowed. For variants with different sizes,
insert a separate product for each size with the same itemGroupId value (
see https://support.google.com/merchants/answer/6324492).
Corresponds to the JSON property size
425 426 427 |
# File 'lib/google/apis/css_v1/classes.rb', line 425 def size @size end |
#size_system ⇒ String
System in which the size is specified. Recommended for apparel items.
Corresponds to the JSON property sizeSystem
430 431 432 |
# File 'lib/google/apis/css_v1/classes.rb', line 430 def size_system @size_system end |
#size_types ⇒ Array<String>
The cut of the item. It can be used to represent combined size types for
apparel items. Maximum two of size types can be provided (see size type.
Corresponds to the JSON property sizeTypes
437 438 439 |
# File 'lib/google/apis/css_v1/classes.rb', line 437 def size_types @size_types end |
#title ⇒ String
Title of the item.
Corresponds to the JSON property title
442 443 444 |
# File 'lib/google/apis/css_v1/classes.rb', line 442 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/google/apis/css_v1/classes.rb', line 449 def update!(**args) @additional_image_links = args[:additional_image_links] if args.key?(:additional_image_links) @adult = args[:adult] if args.key?(:adult) @age_group = args[:age_group] if args.key?(:age_group) @brand = args[:brand] if args.key?(:brand) @certifications = args[:certifications] if args.key?(:certifications) @color = args[:color] if args.key?(:color) @cpp_ads_redirect = args[:cpp_ads_redirect] if args.key?(:cpp_ads_redirect) @cpp_link = args[:cpp_link] if args.key?(:cpp_link) @cpp_mobile_link = args[:cpp_mobile_link] if args.key?(:cpp_mobile_link) @custom_label0 = args[:custom_label0] if args.key?(:custom_label0) @custom_label1 = args[:custom_label1] if args.key?(:custom_label1) @custom_label2 = args[:custom_label2] if args.key?(:custom_label2) @custom_label3 = args[:custom_label3] if args.key?(:custom_label3) @custom_label4 = args[:custom_label4] if args.key?(:custom_label4) @description = args[:description] if args.key?(:description) @excluded_destinations = args[:excluded_destinations] if args.key?(:excluded_destinations) @expiration_date = args[:expiration_date] if args.key?(:expiration_date) @gender = args[:gender] if args.key?(:gender) @google_product_category = args[:google_product_category] if args.key?(:google_product_category) @gtin = args[:gtin] if args.key?(:gtin) @headline_offer_condition = args[:headline_offer_condition] if args.key?(:headline_offer_condition) @headline_offer_installment = args[:headline_offer_installment] if args.key?(:headline_offer_installment) @headline_offer_link = args[:headline_offer_link] if args.key?(:headline_offer_link) @headline_offer_mobile_link = args[:headline_offer_mobile_link] if args.key?(:headline_offer_mobile_link) @headline_offer_price = args[:headline_offer_price] if args.key?(:headline_offer_price) @headline_offer_shipping_price = args[:headline_offer_shipping_price] if args.key?(:headline_offer_shipping_price) @headline_offer_subscription_cost = args[:headline_offer_subscription_cost] if args.key?(:headline_offer_subscription_cost) @high_price = args[:high_price] if args.key?(:high_price) @image_link = args[:image_link] if args.key?(:image_link) @included_destinations = args[:included_destinations] if args.key?(:included_destinations) @is_bundle = args[:is_bundle] if args.key?(:is_bundle) @item_group_id = args[:item_group_id] if args.key?(:item_group_id) @low_price = args[:low_price] if args.key?(:low_price) @material = args[:material] if args.key?(:material) @max_rating = args[:max_rating] if args.key?(:max_rating) @min_rating = args[:min_rating] if args.key?(:min_rating) @mpn = args[:mpn] if args.key?(:mpn) @multipack = args[:multipack] if args.key?(:multipack) @number_of_offers = args[:number_of_offers] if args.key?(:number_of_offers) @pattern = args[:pattern] if args.key?(:pattern) @pause = args[:pause] if args.key?(:pause) @product_details = args[:product_details] if args.key?(:product_details) @product_height = args[:product_height] if args.key?(:product_height) @product_highlights = args[:product_highlights] if args.key?(:product_highlights) @product_length = args[:product_length] if args.key?(:product_length) @product_types = args[:product_types] if args.key?(:product_types) @product_weight = args[:product_weight] if args.key?(:product_weight) @product_width = args[:product_width] if args.key?(:product_width) @rating = args[:rating] if args.key?(:rating) @review_count = args[:review_count] if args.key?(:review_count) @size = args[:size] if args.key?(:size) @size_system = args[:size_system] if args.key?(:size_system) @size_types = args[:size_types] if args.key?(:size_types) @title = args[:title] if args.key?(:title) end |