Class: Google::Apis::CssV1::QuotaGroup
- Inherits:
-
Object
- Object
- Google::Apis::CssV1::QuotaGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/css_v1/classes.rb,
lib/google/apis/css_v1/representations.rb,
lib/google/apis/css_v1/representations.rb
Overview
The group information for methods in the CSS API. The quota is shared between all methods in the group. Even if none of the methods within the group have usage the information for the group is returned.
Instance Attribute Summary collapse
-
#method_details ⇒ Array<Google::Apis::CssV1::MethodDetails>
Output only.
-
#name ⇒ String
Identifier.
-
#quota_limit ⇒ Fixnum
Output only.
-
#quota_minute_limit ⇒ Fixnum
Output only.
-
#quota_usage ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotaGroup
constructor
A new instance of QuotaGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotaGroup
Returns a new instance of QuotaGroup.
1253 1254 1255 |
# File 'lib/google/apis/css_v1/classes.rb', line 1253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#method_details ⇒ Array<Google::Apis::CssV1::MethodDetails>
Output only. List of all methods group quota applies to.
Corresponds to the JSON property methodDetails
1227 1228 1229 |
# File 'lib/google/apis/css_v1/classes.rb', line 1227 def method_details @method_details end |
#name ⇒ String
Identifier. The resource name of the quota group. Format: accounts/account/
quotas/group Example: accounts/12345678/quotas/css-products-insert Note:
The group part is not guaranteed to follow a specific pattern.
Corresponds to the JSON property name
1234 1235 1236 |
# File 'lib/google/apis/css_v1/classes.rb', line 1234 def name @name end |
#quota_limit ⇒ Fixnum
Output only. The maximum number of calls allowed per day for the group.
Corresponds to the JSON property quotaLimit
1239 1240 1241 |
# File 'lib/google/apis/css_v1/classes.rb', line 1239 def quota_limit @quota_limit end |
#quota_minute_limit ⇒ Fixnum
Output only. The maximum number of calls allowed per minute for the group.
Corresponds to the JSON property quotaMinuteLimit
1244 1245 1246 |
# File 'lib/google/apis/css_v1/classes.rb', line 1244 def quota_minute_limit @quota_minute_limit end |
#quota_usage ⇒ Fixnum
Output only. The current quota usage, meaning the number of calls already made
on a given day to the methods in the group. The daily quota limits reset at at
12:00 PM midday UTC.
Corresponds to the JSON property quotaUsage
1251 1252 1253 |
# File 'lib/google/apis/css_v1/classes.rb', line 1251 def quota_usage @quota_usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1258 1259 1260 1261 1262 1263 1264 |
# File 'lib/google/apis/css_v1/classes.rb', line 1258 def update!(**args) @method_details = args[:method_details] if args.key?(:method_details) @name = args[:name] if args.key?(:name) @quota_limit = args[:quota_limit] if args.key?(:quota_limit) @quota_minute_limit = args[:quota_minute_limit] if args.key?(:quota_minute_limit) @quota_usage = args[:quota_usage] if args.key?(:quota_usage) end |